==> qupzilla_1.4.1.orig.tar.gz: qupzilla-1.4.1.orig/src/plugins/PIM/translations/sr_BA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.0">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>Last Name</source>
        <translation>Презиме</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>First Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>E-mail</source>
        <translation>Е-адресу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Mobile</source>
        <translation>Бр. мобилног</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Phone</source>
        <translation>Бр. телефона</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>Address</source>
        <translation>Адресу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>City</source>
        <translation>Град</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>ZIP Code</source>
        <translation>Пошт. број</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>State/Region</source>
        <translation>Сав. држ./регију</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Country</source>
        <translation>Државу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Home Page</source>
        <translation>Домаћу страницу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 1</source>
        <translation>Посебно 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 2</source>
        <translation>Посебно 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="73"/>
        <source>Custom 3</source>
        <translation>Посебно 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="115"/>
        <source>Insert Personal Information</source>
        <translation>Уметни лични податак</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="136"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>ПИМ подешавања</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Менаџер личних података&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>Ваши лични подаци које можете да користите на веб страницама.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Презиме:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>Е-адреса:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Број телефона:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Број мобилног тел:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Адреса:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Град:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Поштански број:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Савезна држ./регија:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>Држава:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Домаћа страница:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Посебно 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Посебно 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Посебно 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Напомена:&lt;/b&gt; Притисните Ctrl+ENTER да бисте аутоматски попунили поља за која Капзила пронађе личне податке.</translation>
    </message>
</context>
</TS>

==> qupzilla_1.6.0.orig.tar.gz: qupzilla-1.6.0/src/plugins/PIM/translations/sr_BA.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr_BA" version="2.0">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>Last Name</source>
        <translation>Презиме</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>First Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>E-mail</source>
        <translation>Е-адресу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Mobile</source>
        <translation>Бр. мобилног</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Phone</source>
        <translation>Бр. телефона</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>Address</source>
        <translation>Адресу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>City</source>
        <translation>Град</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>ZIP Code</source>
        <translation>Пошт. број</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>State/Region</source>
        <translation>Сав. држ./регију</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Country</source>
        <translation>Државу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Home Page</source>
        <translation>Домаћу страницу</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 1</source>
        <translation>Посебно 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 2</source>
        <translation>Посебно 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="73"/>
        <source>Custom 3</source>
        <translation>Посебно 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="115"/>
        <source>Insert Personal Information</source>
        <translation>Уметни лични податак</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="136"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>ПИМ подешавања</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Менаџер личних података&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>Ваши лични подаци које можете да користите на веб страницама.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Име:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Презиме:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>Е-адреса:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Број телефона:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Број мобилног тел:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Адреса:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Град:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Поштански број:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Савезна држ./регија:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>Држава:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Домаћа страница:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Посебно 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Посебно 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Посебно 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Напомена:&lt;/b&gt; Притисните Ctrl+ENTER да бисте аутоматски попунили поља за која Капзила пронађе личне податке.</translation>
    </message>
</context>
</TS>
